@@ -12,31 +12,35 @@
 
 # Written by Henry 'Pi' James
 
-from sys import *
-from os.path import *
-from sha import *
-from BitTorrent.bencode import *
+import gettext
+gettext.install('bittorrent', 'locale')
 
-NAME, EXT = splitext(basename(argv[0]))
-VERSION = '20021119'
+import os.path
 
-print '%s %s - change the suggested filename in a .torrent file' % (NAME, VERSION)
+from sys import argv, exit
+from BitTorrent.bencode import bdecode, bencode
+from BitTorrent import version, app_name
+
+NAME, EXT = os.path.splitext(os.path.basename(argv[0]))
+
+print _("%s %s - change the suggested filename in a .torrent file") % (NAME,
+                                                                    version)
 print
 
 if len(argv) != 3:
-  print '%s file.torrent new.filename.ext' % argv[0]
+  print _("Usage: %s TORRENTFILE NEW_FILE_NAME") % argv[0]
   print
   exit(2) # common exit code for syntax error
 
 metainfo_file = open(argv[1], 'rb')
 metainfo = bdecode(metainfo_file.read())
 metainfo_file.close()
-print 'old filename: %s' % metainfo['info']['name']
+print _("old filename: %s") % metainfo['info']['name']
 metainfo['info']['name'] = argv[2]
-print 'new filename: %s' % metainfo['info']['name']
+print _("new filename: %s") % metainfo['info']['name']
 metainfo_file = open(argv[1], 'wb')
 metainfo_file.write(bencode(metainfo))
 metainfo_file.close
 print
-print 'done.'
+print _("done.")
 print
