@@ -1,3 +1,13 @@
+# The contents of this file are subject to the BitTorrent Open Source License
+# Version 1.0 (the License).  You may not copy or use this file, in either
+# source code or executable form, except in compliance with the License.  You
+# may obtain a copy of the License at http://www.bittorrent.com/license/.
+#
+# Software distributed under the License is distributed on an AS IS basis,
+# WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
+# for the specific language governing rights and limitations under the
+# License.
+
 ### generate a bunch of nodes that use a single contact point
 usage = "usage: inserter.py <contact host> <contact port>"
 
@@ -5,7 +15,7 @@ from utkhashmir import UTKhashmir
 from BitTorrent.RawServer import RawServer
 from BitTorrent.defaultargs import common_options, rare_options
 from khashmir.khash import newID
-from whrandom import randrange
+from random import randrange
 from threading import Event
 import sys, os
 
