@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-
 # The contents of this file are subject to the BitTorrent Open Source License
 # Version 1.0 (the License).  You may not copy or use this file, in either
 # source code or executable form, except in compliance with the License.  You
@@ -12,9 +10,17 @@
 
 # Written by Bram Cohen and Matt Chisholm
 
+import os
+import sys
 from distutils.core import setup
 import py2exe
 import glob
+from BitTorrent import languages
+
+if os.name != 'nt':
+    print "This script is only for use on Win32. Use setup.py to install on a Unix OS."
+    sys.exit()
+
 
 opts = {
     "py2exe": {
@@ -37,12 +43,19 @@ opts = {
     }
 }
 
-langs = ["fr",]
 translations = []
-for l in langs:
-    translations.append (("locale\\%s\\LC_MESSAGES"                % l,
-                          ["locale\\%s\\LC_MESSAGES\\bittorrent.mo" % l,
-                           "locale\\%s\\LC_MESSAGES\\bittorrent.po" % l,]))
+for l in languages:
+    translations.append(("locale\\%s\\LC_MESSAGES"                 % l,
+                         ["locale\\%s\\LC_MESSAGES\\bittorrent.mo" % l,
+                          #"locale\\%s\\LC_MESSAGES\\bittorrent.po" % l,
+                          ]))
+    gtk_mo = []
+    gtk_path = "C:\\GTK\\share\\locale\\%s\\LC_MESSAGES" % l
+    for fn in ("glib20.mo", "gtk20.mo", "gtk20-properties.mo"):
+        moname = os.path.join(gtk_path, fn)
+        if os.access(moname, os.F_OK):
+            gtk_mo.append(moname) 
+    translations.append(("share\\locale\\%s\\LC_MESSAGES" % l, gtk_mo))
 
 setup(windows=[{'script': 'btdownloadgui.py',
                 "icon_resources": [(1, "images\\bittorrent.ico")]},
